Contributing
====================================

Development Workflow
----------------------------


Documentation
--------------
Documentation is produced by Sphinx and can be run by executing::

  make html

Roadmap
-------

Testing
--------

To run::

    pytest

Continuous Integration
----------------------------
